@@ -13,7 +13,13 @@ const libaws_c_http_path = "/usr/lib/libaws-c-http.so.1.0.0"
 libaws_c_http_handle = C_NULL
 get_libaws_c_http_path() = libaws_c_http_path
 const libaws_c_http = "libaws-c-http.so.1.0.0"
+export libaws_c_http_jq
+const libaws_c_http_jq_path = "/usr/lib/libaws-c-http.so.1.0.0"
+libaws_c_http_jq_handle = C_NULL
+get_libaws_c_http_jq_path() = libaws_c_http_jq_path
+const libaws_c_http_jq = "libaws-c-http.so.1.0.0"
 function __init__()
     global libaws_c_http_handle = dlopen(libaws_c_http_path)
+    global libaws_c_http_jq_handle = dlopen(libaws_c_http_jq_path)
 end
 end
